@@ -50,7 +50,7 @@ char* gStatmentKindStrs[kCommand+1] = {
     "while", "break", "exit", "if", "split", 
     "x", "join", "select", "lines", "rows",
     "match", "scan", "erase", "sub",  
-    "read",
+    "read", "close",
     "cd", 
     "add", "del",  "selector", "max", "min", "extname", 
     "parentname", "noextname", 
@@ -2213,7 +2213,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.0.7", 1);
+    setenv("SAPHIRE_VERSION", "3.0.8", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
