@@ -73,14 +73,14 @@ static BOOL statment_tree_redirect(sCommand* command, sRFd ** nextin, sWFd** nex
                             *nextout = sWFd_new(openfd);
                         }
                         else {
-                            if((*nextout)->mFd != -1) {
-                                close((*nextout)->mFd);
+                            if((*nextout)->mFd != -1 && (*nextout)->mFd != 1) {
+                                (void)close((*nextout)->mFd);
                             }
                             (*nextout)->mFd = openfd;
                         }
                     }
                     else {
-                        if(*nexterr != 2 && *nexterr != pipeerr) close(*nexterr);
+                        if(*nexterr != 2 && *nexterr != pipeerr) (void)close(*nexterr);
                         
                         *nexterr = openfd;
                     }
@@ -92,14 +92,14 @@ static BOOL statment_tree_redirect(sCommand* command, sRFd ** nextin, sWFd** nex
                             *nextout = sWFd_new(openfd);
                         }
                         else {
-                            if((*nextout)->mFd != -1) {
-                                close((*nextout)->mFd);
+                            if((*nextout)->mFd != -1 && (*nextout)->mFd != 1) {
+                                (void)close((*nextout)->mFd);
                             }
                             (*nextout)->mFd = openfd;
                         }
                     }
                     else {
-                        if(*nexterr != 2 && *nexterr != pipeerr) close(*nexterr);
+                        if(*nexterr != 2 && *nexterr != pipeerr) (void)close(*nexterr);
                         
                         *nexterr = openfd;
                     }
@@ -142,31 +142,31 @@ static BOOL statment_tree_exec_cprog(sCommand* command, int nextin, int nextout,
 
             int openfd = open(string_c_str(redirect->mFName), mode, 0666);
             if(openfd < 0) {
-               char buf[PATH_MAX];
-               snprintf(buf, PATH_MAX, "open %s is err2\n"
-                                , string_c_str(redirect->mFName));
-               err_msg(buf, sname, sline);
-               return FALSE; 
+                char buf[PATH_MAX];
+                snprintf(buf, PATH_MAX, "open %s is err2\n"
+                                 , string_c_str(redirect->mFName));
+                err_msg(buf, sname, sline);
+                return FALSE; 
             }
             
             switch(redirect->mFd) {
                 case 0:
                     if(nextin != 0 && nextin != -1) {
-                        close(nextin);
+                        (void)close(nextin);
                     }
                     nextin = openfd;
                     break;
                     
                 case 1:
                     if(nextout != 1 && nextout != -1) {
-                        close(nextout);
+                        (void)close(nextout);
                     }
                     nextout = openfd;
                     break;
                     
                 case 2:
                     if(nexterr != 2) {
-                        close(nexterr);
+                        (void)close(nexterr);
                     }
                     nexterr = openfd;
                     break;
@@ -267,10 +267,10 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
 
     /// 子プロセスの処理 ///
     if(pid == 0) {
-        if(mpipefds[0] != -1) close(mpipefds[0]);
-        if(mpipefds[1] != -1) close(mpipefds[1]);
-        if(mpipefds2[0] != -1) close(mpipefds2[0]);
-        if(mpipefds2[1] != -1) close(mpipefds2[1]);
+        if(mpipefds[0] != -1) (void)close(mpipefds[0]);
+        if(mpipefds[1] != -1) (void)close(mpipefds[1]);
+        if(mpipefds2[0] != -1) (void)close(mpipefds2[0]);
+        if(mpipefds2[1] != -1) (void)close(mpipefds2[1]);
 
         pid = getpid();
 
@@ -329,7 +329,7 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
                 }
 
                 if(mpipefds[1] != -1) {
-                    close(nextin2);
+                    (void)close(nextin2);
                     BOOL epipe = FALSE;
                     if(!gSigUser && write(mpipefds[1], string_c_str(nextin->mBuffer), string_length(nextin->mBuffer)) < 0)
                     {
@@ -338,7 +338,7 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
                             exit(1);
                         }
                     }
-                    close(mpipefds[1]);
+                    (void)close(mpipefds[1]);
                 }
                 exit(0);
             }
@@ -349,12 +349,12 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
                 }
 
                 if(mpipefds[1] != -1) {
-                    close(nextin2);
-                    close(mpipefds[1]);
+                    (void)close(nextin2);
+                    (void)close(mpipefds[1]);
                 }
 
                 if(mpipefds2[0] != -1) {
-                    close(nextout2);
+                    (void)close(nextout2);
 
                     if(!gSigUser) {
                         char buf[BUFSIZ+1];
@@ -386,7 +386,7 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
                         }
                     }
 
-                    close(mpipefds2[0]);
+                    (void)close(mpipefds2[0]);
                 }
             }
             if(gAppType == kATOptC) {
@@ -421,7 +421,7 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
         }
         else {
             if(mpipefds2[0] != -1) {
-                close(nextout2);
+                (void)close(nextout2);
 
                 if(!gSigUser) {
                     char buf[BUFSIZ+1];
@@ -453,7 +453,7 @@ static BOOL statment_tree_external_command(sStatment* statment, vector_obj* argv
                     }
                 }
 
-                close(mpipefds2[0]);
+                (void)close(mpipefds2[0]);
             }
         }
 
@@ -596,7 +596,7 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                     exit(1);
                 }
 
-                close(fd);
+                (void)close(fd);
 
                 vector_add(argv, STRING_NEW(fname));
                 }
@@ -1218,7 +1218,7 @@ int saphire_load(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr)
             break;
         }
         if(size < 0) {
-            close(f);
+            (void)close(f);
             return -1;
         }
 
@@ -1226,7 +1226,7 @@ int saphire_load(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr)
 
         string_push_back(str, buf);
     }
-    close(f);
+    (void)close(f);
 
     int rcode = saphire_shell(string_c_str(str), fname, pipeout, pipein, pipeerr);
 
